==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/CheckboxBase.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { CheckboxBaseLabelPosition_$type } from "./CheckboxBaseLabelPosition";
import { ComponentBoolValueChangedEventArgs } from "./ComponentBoolValueChangedEventArgs";
import { VoidEventArgs } from "./VoidEventArgs";
/**
 * @hidden
 */
var CheckboxBase = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CheckboxBase, _super);
    function CheckboxBase() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.e = new WCNativeHelper();
        _this.k = null;
        _this.change = null;
        _this.focus = null;
        _this.blur = null;
        return _this;
    }
    Object.defineProperty(CheckboxBase.prototype, "f", {
        get: function () {
            return this.e;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CheckboxBase.prototype, "nativeElement", {
        get: function () {
            return this.k;
        },
        set: function (a) {
            this.k = a;
            this.e.n = this.k;
        },
        enumerable: false,
        configurable: true
    });
    CheckboxBase.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(CheckboxBase.prototype, "n", {
        get: function () {
            var ret_ = this.f.m("name");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("name", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CheckboxBase.prototype, "o", {
        get: function () {
            var ret_ = this.f.m("value");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("value", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CheckboxBase.prototype, "h", {
        get: function () {
            var ret_ = this.f.m("disabled");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("disabled", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CheckboxBase.prototype, "g", {
        get: function () {
            var ret_ = this.f.m("checked");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("checked", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CheckboxBase.prototype, "j", {
        get: function () {
            var ret_ = this.f.m("required");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("required", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CheckboxBase.prototype, "i", {
        get: function () {
            var ret_ = this.f.m("invalid");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("invalid", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CheckboxBase.prototype, "a", {
        get: function () {
            var ret_ = this.f.m("labelPosition");
            ret_ = enumGetBox(CheckboxBaseLabelPosition_$type, EnumUtil.getEnumValue(CheckboxBaseLabelPosition_$type, this.f.f(CheckboxBaseLabelPosition_$type, ret_)));
            return EnumUtil.getEnumValue(CheckboxBaseLabelPosition_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(CheckboxBaseLabelPosition_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.f.u("labelPosition", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CheckboxBase.prototype, "m", {
        get: function () {
            var ret_ = this.f.m("ariaLabelledby");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("ariaLabelledby", value_);
        },
        enumerable: false,
        configurable: true
    });
    CheckboxBase.prototype.changeChanged = function () {
        var _this = this;
        if (this.change != null) {
            this.f.q("change", function (a) { return _this.change(_this, ComponentBoolValueChangedEventArgs.a(a)); });
        }
        else {
            this.f.t("change");
        }
    };
    CheckboxBase.prototype.focusChanged = function () {
        var _this = this;
        if (this.focus != null) {
            this.f.q("focus", function (a) { return _this.focus(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.f.t("focus");
        }
    };
    CheckboxBase.prototype.blurChanged = function () {
        var _this = this;
        if (this.blur != null) {
            this.f.q("blur", function (a) { return _this.blur(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.f.t("blur");
        }
    };
    CheckboxBase.prototype.t = function () {
        this.nativeElement.click();
    };
    CheckboxBase.prototype.x = function (a) {
        this.nativeElement.focus(this.f.h(a));
    };
    CheckboxBase.prototype.q = function () {
        this.nativeElement.blur();
    };
    CheckboxBase.prototype.y = function () {
        this.nativeElement.reportValidity();
    };
    CheckboxBase.prototype.s = function () {
        this.nativeElement.checkValidity();
    };
    CheckboxBase.prototype.z = function (a) {
        this.nativeElement.setCustomValidity(this.f.h(a));
    };
    CheckboxBase.prototype.u = function () {
        this.nativeElement.connectedCallback();
    };
    CheckboxBase.prototype.v = function () {
        this.nativeElement.disconnectedCallback();
    };
    CheckboxBase.$t = markType(CheckboxBase, 'CheckboxBase', BaseElement.$);
    return CheckboxBase;
}(BaseElement));
export { CheckboxBase };

==> igniteui-react-18.3.0-beta.0.tgz: package/esm5/lib/CheckboxBase.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { CheckboxBaseLabelPosition_$type } from "./CheckboxBaseLabelPosition";
import { ComponentBoolValueChangedEventArgs } from "./ComponentBoolValueChangedEventArgs";
import { VoidEventArgs } from "./VoidEventArgs";
/**
 * @hidden
 */
var CheckboxBase = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CheckboxBase, _super);
    function CheckboxBase() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.e = new WCNativeHelper();
        _this.k = null;
        _this.change = null;
        _this.focus = null;
        _this.blur = null;
        return _this;
    }
    Object.defineProperty(CheckboxBase.prototype, "f", {
        get: function () {
            return this.e;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CheckboxBase.prototype, "nativeElement", {
        get: function () {
            return this.k;
        },
        set: function (a) {
            this.k = a;
            this.e.o = this.k;
        },
        enumerable: false,
        configurable: true
    });
    CheckboxBase.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(CheckboxBase.prototype, "n", {
        get: function () {
            var ret_ = this.f.n("name");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("name", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CheckboxBase.prototype, "o", {
        get: function () {
            var ret_ = this.f.n("value");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("value", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CheckboxBase.prototype, "h", {
        get: function () {
            var ret_ = this.f.n("disabled");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("disabled", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CheckboxBase.prototype, "g", {
        get: function () {
            var ret_ = this.f.n("checked");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("checked", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CheckboxBase.prototype, "j", {
        get: function () {
            var ret_ = this.f.n("required");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("required", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CheckboxBase.prototype, "i", {
        get: function () {
            var ret_ = this.f.n("invalid");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("invalid", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CheckboxBase.prototype, "a", {
        get: function () {
            var ret_ = this.f.n("labelPosition");
            ret_ = enumGetBox(CheckboxBaseLabelPosition_$type, EnumUtil.getEnumValue(CheckboxBaseLabelPosition_$type, this.f.f(CheckboxBaseLabelPosition_$type, ret_)));
            return EnumUtil.getEnumValue(CheckboxBaseLabelPosition_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(CheckboxBaseLabelPosition_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.f.v("labelPosition", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CheckboxBase.prototype, "m", {
        get: function () {
            var ret_ = this.f.n("ariaLabelledby");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("ariaLabelledby", value_);
        },
        enumerable: false,
        configurable: true
    });
    CheckboxBase.prototype.changeChanged = function () {
        var _this = this;
        if (this.change != null) {
            this.f.r("change", function (a) { return _this.change(_this, ComponentBoolValueChangedEventArgs.a(a)); });
        }
        else {
            this.f.u("change");
        }
    };
    CheckboxBase.prototype.focusChanged = function () {
        var _this = this;
        if (this.focus != null) {
            this.f.r("focus", function (a) { return _this.focus(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.f.u("focus");
        }
    };
    CheckboxBase.prototype.blurChanged = function () {
        var _this = this;
        if (this.blur != null) {
            this.f.r("blur", function (a) { return _this.blur(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.f.u("blur");
        }
    };
    CheckboxBase.prototype.t = function () {
        this.nativeElement.click();
    };
    CheckboxBase.prototype.x = function (a) {
        this.nativeElement.focus(this.f.i(a));
    };
    CheckboxBase.prototype.q = function () {
        this.nativeElement.blur();
    };
    CheckboxBase.prototype.y = function () {
        this.nativeElement.reportValidity();
    };
    CheckboxBase.prototype.s = function () {
        this.nativeElement.checkValidity();
    };
    CheckboxBase.prototype.z = function (a) {
        this.nativeElement.setCustomValidity(this.f.i(a));
    };
    CheckboxBase.prototype.u = function () {
        this.nativeElement.connectedCallback();
    };
    CheckboxBase.prototype.v = function () {
        this.nativeElement.disconnectedCallback();
    };
    CheckboxBase.$t = markType(CheckboxBase, 'CheckboxBase', BaseElement.$);
    return CheckboxBase;
}(BaseElement));
export { CheckboxBase };
